import { Suspense, lazy } from "react";
import { Route, Switch } from "wouter";
import { Card, CardContent } from "@/components/ui/card";
import { AlertCircle, Loader2 } from "lucide-react";
import { Toaster } from "@/components/ui/toaster";
import { useUser } from "@/hooks/use-user";
import { Header } from "@/components/Header";
import { useQuery } from "@tanstack/react-query";
import { Footer } from "@/components/Footer";

// Add type for admin check response
type AdminCheckResponse = {
  isAdmin: boolean;
  role?: string;
  permissions?: string[];
  message?: string;
};

// Group lazy imports by feature
const Auth = {
  AuthPage: lazy(() => import("@/pages/AuthPage")),
  ProfessionalRegistration: lazy(() => import("@/pages/ProfessionalRegistration")),
  CompanyRegistration: lazy(() => import("@/pages/CompanyRegistration"))
};

const Core = {
  Home: lazy(() => import("@/pages/Home")),
  BrowsePage: lazy(() => import("@/pages/BrowsePage")),
  ProjectsPage: lazy(() => import("@/pages/ProjectsPage")),
  ManifestoPage: lazy(() => import("@/pages/ManifestoPage")),
  ResourcesPage: lazy(() => import("@/pages/ResourcesPage")),
  SeasteadsPage: lazy(() => import("@/pages/SeasteadsPage")),
  NetworkStatesPage: lazy(() => import("@/pages/NetworkStatesPage")),
  NationStatesPage: lazy(() => import("@/pages/NationStatesPage")),
  ElSalvadorPage: lazy(() => import("@/pages/ElSalvadorPage")),
  CitiesPage: lazy(() => import("@/pages/CitiesPage")),
  DirectoryPage: lazy(() => import("@/pages/DirectoryPage")),
  EconomicDashboard: lazy(() => import("./pages/EconomicDashboard")), // Using the enhanced version
  TermsPage: lazy(() => import("@/pages/TermsPage")),
  PrivacyPage: lazy(() => import("@/pages/PrivacyPage")),
  DisclaimerPage: lazy(() => import("@/pages/DisclaimerPage")),
  CookiePolicyPage: lazy(() => import("@/pages/CookiePolicyPage")),
  OceanBuildersCustom: lazy(() => import("@/pages/OceanBuildersCustom")),
  AmityAgeAcademy: lazy(() => import("@/pages/AmityAgeAcademy")),
  SeasteadingInstitute: lazy(() => import("@/pages/SeasteadingInstitute")),
  FreeCitiesFoundation: lazy(() => import("@/pages/FreeCitiesFoundation")),
  FreeCitadelsPage: lazy(() => import("@/pages/FreeCitadelsPage")),
  LaunchWithUs: lazy(() => import("@/pages/LaunchWithUs")),
  Collaborate: lazy(() => import("@/pages/Collaborate")),
};

const Properties = {
  PropertyDetail: lazy(() => import("@/pages/PropertyDetail")),
  PropertyEdit: lazy(() => import("@/pages/PropertyEdit"))
};

const Companies = {
  GoodlifeElSalvador: lazy(() => import("@/pages/GoodlifeElSalvador")),
  CompanyDetail: lazy(() => import("@/pages/CompanyDetail")),
  CompanyEdit: lazy(() => import("@/pages/CompanyEdit")),
  CompanyCreation: lazy(() => import("@/pages/CompanyCreation"))
};

const Professionals = {
  ProfessionalDetail: lazy(() => import("@/pages/ProfessionalDetail")),
  ProfessionalRegistration: lazy(() => import("@/pages/ProfessionalRegistration"))
};

const Projects = {
  ProjectCreation: lazy(() => import("@/pages/ProjectCreation")),
  ProjectDetail: lazy(() => import("@/pages/ProjectDetail")),
  ProjectEdit: lazy(() => import("@/pages/ProjectEdit")),
  // VivaCityProject has been removed
  PraxisSocietyProject: lazy(() => import("@/pages/PraxisSocietyProject")),
  InfinitaCityProject: lazy(() => import("@/pages/InfinitaCityProject")),
  ArcProject: lazy(() => import("@/pages/ArcProject")),
  ProsperaProject: lazy(() => import("@/pages/ProsperaProject")),
  VeritasVillage: lazy(() => import("@/pages/VeritasVillage")),
  ArkpadReefProject: lazy(() => import("@/pages/ArkpadReefProject")),
  LoftSunsetViewProject: lazy(() => import("@/pages/LoftSunsetViewProject")),
  LarcidadProject: lazy(() => import("@/pages/LarcidadProject")),
  NomadCityProject: lazy(() => import("@/pages/NomadCityProject")),
  CuldesacProject: lazy(() => import("@/pages/CuldesacProject"))
};

const Admin = {
  AdminDashboard: lazy(() => import("@/pages/AdminDashboard")),
  UserEdit: lazy(() => import("@/pages/UserEdit")),
  NetworkStateEdit: lazy(() => import("@/pages/NetworkStateEdit")),
  NationStateEdit: lazy(() => import("@/pages/NationStateEdit")),
  EmailManagement: lazy(() => import("@/pages/EmailManagement"))
};

const Profile = {
  ProfileDashboard: lazy(() => import("@/pages/ProfileDashboard"))
};

// Enhanced loading component
const PageLoader = () => (
  <div className="flex items-center justify-center min-h-[50vh] animate-in fade-in duration-300">
    <Loader2 className="h-8 w-8 animate-spin text-primary" />
  </div>
);

// Optimized Layout component with error boundary
function Layout({ children }: { children: React.ReactNode }) {
  return (
    <div className="min-h-screen flex flex-col">
      <Header />
      <main className="flex-1">
        <Suspense
          fallback={<PageLoader />}
          >
          {children}
        </Suspense>
      </main>
      <Footer />
    </div>
  );
}

// ProtectedRoute component remains unchanged
function ProtectedRoute({ component: Component }: { component: React.ComponentType }) {
  const { user, isLoading } = useUser();

  if (isLoading) {
    return <PageLoader />;
  }

  if (!user) {
    return <Auth.AuthPage />;
  }

  return (
    <Suspense fallback={<PageLoader />}>
      <Component />
    </Suspense>
  );
}

// ProtectedAdminRoute component remains unchanged
function ProtectedAdminRoute({ component: Component }: { component: React.ComponentType }) {
  const { user, isLoading } = useUser();
  const { data: adminStatus, isLoading: isAdminLoading } = useQuery<AdminCheckResponse>({
    queryKey: ["/api/admin/check"],
    enabled: !!user,
  });

  if (isLoading || isAdminLoading) {
    return <PageLoader />;
  }

  if (!user) {
    return <Auth.AuthPage />;
  }

  if (!adminStatus?.isAdmin) {
    return (
      <div className="min-h-screen w-full flex items-center justify-center bg-gray-50">
        <Card className="w-full max-w-md mx-4">
          <CardContent className="pt-6">
            <div className="flex mb-4 gap-2">
              <AlertCircle className="h-8 w-8 text-red-500" />
              <h1 className="text-2xl font-bold text-gray-900">Unauthorized Access</h1>
            </div>
            <p className="mt-4 text-sm text-gray-600">
              You do not have permission to access this area.
            </p>
          </CardContent>
        </Card>
      </div>
    );
  }

  return (
    <Suspense fallback={<PageLoader />}>
      <Component />
    </Suspense>
  );
}


function App() {
  return (
    <Layout>
      <Switch>
        <Route path="/" component={Core.Home} />
        <Route path="/auth" component={Auth.AuthPage} />
        <Route path="/properties" component={Core.BrowsePage} />
        <Route path="/directory" component={Core.DirectoryPage} />
        <Route path="/seasteads" component={Core.SeasteadsPage} />
        <Route path="/network-states" component={Core.NetworkStatesPage} />
        <Route path="/nation-states" component={Core.NationStatesPage} />
        <Route path="/nation-states/el-salvador" component={Core.ElSalvadorPage} />
        <Route path="/cities" component={Core.CitiesPage} />
        <Route path="/economic-dashboard" component={Core.EconomicDashboard} />
        <Route path="/manifesto" component={Core.ManifestoPage} />
        <Route path="/terms" component={Core.TermsPage} />
        <Route path="/privacy" component={Core.PrivacyPage} />
        <Route path="/disclaimer" component={Core.DisclaimerPage} />
        <Route path="/cookies" component={Core.CookiePolicyPage} />
        <Route path="/collaborate" component={Core.Collaborate} />
        <Route path="/property/custom-ob" component={Core.OceanBuildersCustom} />
        <Route path="/property/:id" component={Properties.PropertyDetail} />
        <Route path="/professionals/:id" component={Professionals.ProfessionalDetail} />
        <Route path="/companies/goodlife-el-salvador" component={Companies.GoodlifeElSalvador} />
        <Route path="/companies/:id" component={Companies.CompanyDetail} />
        <Route path="/projects" component={Core.ProjectsPage} />
        <Route path="/projects/new" component={() => <ProtectedRoute component={Projects.ProjectCreation} />} />
        <Route path="/projects/viva-city" component={NotFound} />
        <Route path="/projects/praxis" component={Projects.PraxisSocietyProject} />
        <Route path="/projects/infinita-city" component={Projects.InfinitaCityProject} />
        <Route path="/projects/arc" component={Projects.ArcProject} />
        <Route path="/projects/prospera" component={Projects.ProsperaProject} />
        <Route path="/projects/veritas-village" component={Projects.VeritasVillage} />
        <Route path="/projects/arkpad-reef" component={Projects.ArkpadReefProject} />
        <Route path="/projects/loft-sunset-view" component={Projects.LoftSunsetViewProject} />
        <Route path="/projects/larcidad" component={Projects.LarcidadProject} />
        <Route path="/projects/nomad-city" component={Projects.NomadCityProject} />
        <Route path="/projects/culdesac" component={Projects.CuldesacProject} />
        <Route path="/projects/:id" component={Projects.ProjectDetail} />
        <Route path="/resources" component={Core.ResourcesPage} />
        <Route path="/resources/amityage-academy" component={Core.AmityAgeAcademy} />
        <Route path="/resources/seasteading-institute" component={Core.SeasteadingInstitute} />
        <Route path="/resources/free-cities-foundation" component={Core.FreeCitiesFoundation} />
        <Route path="/resources/free-citadels" component={Core.FreeCitadelsPage} />
        <Route path="/admin" component={() => <ProtectedAdminRoute component={Admin.AdminDashboard} />} />
        <Route path="/admin/users/:id/edit" component={() => <ProtectedAdminRoute component={Admin.UserEdit} />} />
        <Route path="/admin/properties/:id/edit" component={() => <ProtectedAdminRoute component={Properties.PropertyEdit} />} />
        <Route path="/admin/projects/:id/edit" component={() => <ProtectedAdminRoute component={Projects.ProjectEdit} />} />
        <Route path="/admin/companies/:id/edit" component={() => <ProtectedAdminRoute component={Companies.CompanyEdit} />} />
        <Route path="/admin/network-states/:id/edit" component={() => <ProtectedAdminRoute component={Admin.NetworkStateEdit} />} />
        <Route path="/admin/nation-states/:id/edit" component={() => <ProtectedAdminRoute component={Admin.NationStateEdit} />} />
        <Route path="/admin/emails" component={() => <ProtectedAdminRoute component={Admin.EmailManagement} />} />
        <Route path="/profile" component={() => <ProtectedRoute component={Profile.ProfileDashboard} />} />
        <Route path="/professional-registration" component={() => <ProtectedRoute component={Professionals.ProfessionalRegistration} />} />
        <Route path="/company-registration" component={() => <ProtectedRoute component={Auth.CompanyRegistration} />} />
        <Route path="/companies/new" component={() => <ProtectedRoute component={Companies.CompanyCreation} />} />
        <Route path="/professionals/detail/:id" component={Professionals.ProfessionalDetail} />
        <Route path="/companies/detail/:id" component={Companies.CompanyDetail} />
        <Route path="/launch-with-us" component={Core.LaunchWithUs} />
        <Route component={NotFound} />
      </Switch>
      <Toaster />
    </Layout>
  );
}

function NotFound() {
  return (
    <div className="min-h-screen w-full flex items-center justify-center bg-gray-50">
      <Card className="w-full max-w-md mx-4">
        <CardContent className="pt-6">
          <div className="flex mb-4 gap-2">
            <AlertCircle className="h-8 w-8 text-red-500" />
            <h1 className="text-2xl font-bold text-gray-900">404 Page Not Found</h1>
          </div>
          <p className="mt-4 text-sm text-gray-600">
            The page you're looking for doesn't exist.
          </p>
        </CardContent>
      </Card>
    </div>
  );
}

export default App;